@@ -1,5 +1,5 @@
 package XML::Grammar::Fiction::FromProto::Node::Description;
-$XML::Grammar::Fiction::FromProto::Node::Description::VERSION = '0.26.2';
+$XML::Grammar::Fiction::FromProto::Node::Description::VERSION = '0.26.3';
 use strict;
 use warnings;
 
@@ -7,15 +7,6 @@ use MooX 'late';
 
 extends("XML::Grammar::Fiction::FromProto::Node::Text");
 
-around 'get_text' => sub {
-    my $orig = shift;
-    my $self = shift;
-
-    my $ret = ( $orig->( $self, @_ ) );
-    $ret =~ s#[ \t]+$##gms;
-    return $ret;
-};
-
 1;
 
 __END__
@@ -26,7 +17,7 @@ __END__
 
 =head1 VERSION
 
-version 0.26.2
+version 0.26.3
 
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
